@@ -8,7 +8,7 @@ sub isInventoryEnabled {
 
     return unless can_load("Mac::SysProfile");
     # Do not run an package inventory if there is the --nosoft parameter
-    return if ($params->{config}->{nosoft});
+    return if ($params->{config}->{'no-software'});
 
     1;
 }
@@ -28,6 +28,12 @@ sub doInventory {
 
         next unless ref($a) eq 'HASH';
 
+# http://forge.fusioninventory.org/issues/716
+        if ($a->{'Get Info String'} && $a->{'Get Info String'} =~ /\S+, [C-Z]:\\\S+/) {
+            # Windows application found by Parallels
+            next;
+        }
+
         my $kind = $a->{'Kind'} ? $a->{'Kind'} : 'UNKNOWN';
         my $comments = '['.$kind.']';
         $inventory->addSoftware({
