@@ -3,12 +3,9 @@ package FusionInventory::Agent::Task::Inventory::OS::Win32::Memory;
 use strict;
 use warnings;
 
-use FusionInventory::Agent::Task::Inventory::OS::Win32;
+our $runMeIfTheseChecksFailed = ["FusionInventory::Agent::Task::Inventory::OS::Generic::Dmidecode"];
 
-sub isInventoryEnabled {
-# Only if dmidecode is not avalaible
-    return !can_run('dmidecode');
-}
+use FusionInventory::Agent::Task::Inventory::OS::Win32;
 
 my @formFactorVal = qw/
     Unknown 
@@ -85,14 +82,13 @@ sub doInventory {
         Capacity Caption Description FormFactor Removable Speed MemoryType
         SerialNumber
     /)) {
+        if (defined($memoryTypeVal[$Properties->{MemoryType}])) {
+# See: #1334
+                next if $memoryTypeVal[$Properties->{MemoryType}] eq 'Flash';
 # Ignore ROM storages (BIOS ROM)
-        if (defined($memoryTypeVal[$Properties->{MemoryType}]) &&
-$memoryTypeVal[$Properties->{MemoryType}] eq 'ROM') {
-            next;
+                next if $memoryTypeVal[$Properties->{MemoryType}] eq 'ROM';
         }
 
-
-
         my $capacity = sprintf("%i",$Properties->{Capacity}/(1024*1024));
         my $caption = $Properties->{Caption};
         my $description = $Properties->{Description};
